@@ -1,8 +1,8 @@
+from databao.core.agent import Agent
 from databao.core.cache import Cache
 from databao.core.executor import ExecutionResult, Executor
 from databao.core.opa import Opa
 from databao.core.pipe import Pipe
-from databao.core.session import Agent
 from databao.core.visualizer import VisualisationResult, Visualizer
 
 __all__ = ["Agent", "Cache", "ExecutionResult", "Executor", "Opa", "Pipe", "VisualisationResult", "Visualizer"]
